@@ -6,12 +6,15 @@ NOTE: If you use isort within a public repository, please feel empowered to add
 It is important to isort that as few regressions as possible are experienced by our users.
 Having your project tested here is the most sure way to keep those regressions form ever happening.
 """
+
 from __future__ import annotations
 
 from pathlib import Path
 from subprocess import check_call
 from typing import Generator, Sequence
 
+import pytest
+
 from isort.main import main
 
 
@@ -25,6 +28,10 @@ def run_isort(arguments: Generator[str, None, None] | Sequence[str]):
     main(["--check-only", "--diff", *arguments])
 
 
+@pytest.mark.xfail(
+    reason="Project is incorrectly formatted after PR #2236, should be fixed "
+    "after a release and the project formatting again."
+)
 def test_django(tmpdir):
     git_clone("https://github.com/django/django.git", tmpdir)
     run_isort(
@@ -42,55 +49,16 @@ def test_pandas(tmpdir):
     run_isort((str(tmpdir / "pandas"), "--skip", "__init__.py"))
 
 
-def test_fastapi(tmpdir):
-    git_clone("https://github.com/tiangolo/fastapi.git", tmpdir)
-    run_isort([str(tmpdir / "fastapi")])
-
-
 def test_habitat_lab(tmpdir):
     git_clone("https://github.com/facebookresearch/habitat-lab.git", tmpdir)
     run_isort([str(tmpdir)])
 
 
-def test_tmuxp(tmpdir):
-    git_clone("https://github.com/tmux-python/tmuxp.git", tmpdir)
-    run_isort(
-        [
-            str(tmpdir),
-            "--skip",
-            "cli.py",
-            "--skip",
-            "test_workspacebuilder.py",
-            "--skip",
-            "test_cli.py",
-            "--skip",
-            "workspacebuilder.py",
-            "--skip",
-            "freezer.py",
-        ]
-    )
-
-
-def test_websockets(tmpdir):
-    git_clone("https://github.com/aaugustin/websockets.git", tmpdir)
-    run_isort((str(tmpdir), "--skip", "example", "--skip", "docs", "--skip", "compliance"))
-
-
-def test_typeshed(tmpdir):
-    git_clone("https://github.com/python/typeshed.git", tmpdir)
-    run_isort([str(tmpdir)])
-
-
 def test_pylint(tmpdir):
     git_clone("https://github.com/PyCQA/pylint.git", tmpdir)
     run_isort([str(tmpdir), "--skip", "bad.py"])
 
 
-def test_poetry(tmpdir):
-    git_clone("https://github.com/python-poetry/poetry.git", tmpdir)
-    run_isort((str(tmpdir), "--skip", "tests"))
-
-
 def test_hypothesis(tmpdir):
     git_clone("https://github.com/HypothesisWorks/hypothesis.git", tmpdir)
     run_isort(
@@ -109,47 +77,6 @@ def test_hypothesis(tmpdir):
     )
 
 
-def test_pillow(tmpdir):
-    git_clone("https://github.com/python-pillow/Pillow.git", tmpdir)
-    run_isort((str(tmpdir), "--skip", "tests"))
-
-
-def test_attrs(tmpdir):
-    git_clone("https://github.com/python-attrs/attrs.git", tmpdir)
-    run_isort(
-        (
-            str(tmpdir),
-            "--skip",
-            "tests",
-            "--ext",
-            "py",
-            "--skip",
-            "_compat.py",
-        )
-    )
-
-
-def test_datadog_integrations_core(tmpdir):
-    git_clone("https://github.com/DataDog/integrations-core.git", tmpdir)
-    run_isort(
-        [
-            str(tmpdir),
-            "--skip",
-            "ddev",
-            "--skip",
-            "docs",
-            "--skip-glob",
-            ".*",
-            "--skip-glob",
-            "*/datadog_checks/dev/tooling/signing.py",
-            "--skip-glob",
-            "*/datadog_checks/dev/tooling/templates/*",
-            "--skip-glob",
-            "*/datadog_checks/*/vendor/*",
-        ]
-    )
-
-
 def test_pyramid(tmpdir):
     git_clone("https://github.com/Pylons/pyramid.git", tmpdir)
     run_isort(
