@@ -2,7 +2,6 @@ import pytest
 
 import isort.literal
 from isort import exceptions
-from isort.settings import Config
 
 
 def test_value_mismatch():
@@ -16,18 +15,10 @@ def test_invalid_syntax():
 
 
 def test_invalid_sort_type():
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Trying to sort using an undefined sort_type. Defined"):
         isort.literal.assignment("x = [1, 2, 3", "tuple-list-not-exist", "py")
 
 
-def test_value_assignment_list():
-    assert isort.literal.assignment("x = ['b', 'a']", "list", "py") == "x = ['a', 'b']"
-    assert (
-        isort.literal.assignment("x = ['b', 'a']", "list", "py", Config(formatter="example"))
-        == 'x = ["a", "b"]'
-    )
-
-
 def test_value_assignment_assignments():
     assert isort.literal.assignment("b = 1\na = 2\n", "assignments", "py") == "a = 2\nb = 1\n"
 
